@@ -1,4 +1,4 @@
-# Copyright (C) 2022 DigeeX
+# Copyright (C) 2020-2022 DigeeX
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -82,12 +82,6 @@ class Config:
 
         self.logger = get_logger(self.loglevel, "raider")
 
-        if not list_projects():
-            self.logger.critical(
-                "No application have been configured. Cannot run."
-            )
-            sys.exit()
-
     def write_config_file(self) -> None:
         """Writes global configuration to common.hy.
 
